<?php
namespace iubenda\cookiesolution\Observer;

use Magento\Framework\Event\ObserverInterface;
use iubenda\cookiesolution\Helper\Data as HelperData;

class ProcessHTML implements ObserverInterface {
	protected $_helperData;
	protected $_directory_list;

	/**
	 * Class constructor
	 */
	public function __construct( HelperData $helperData, \Magento\Framework\App\Filesystem\DirectoryList $directory_list ) {
		$this->_helperData = $helperData;
		$this->_directory_list = $directory_list;  
	}

	/**
	 * Update HTML using iubenda class.
	 *
	 * @param \Magento\Framework\Event\Observer $observer
	 * @return void
	 */
	public function execute( \Magento\Framework\Event\Observer $observer ) {
		if ( $this->_helperData->is_blocking_enabled() ) {
			$iubenda_path = $this->_directory_list->getPath( 'app' ) . '/code/iubenda/cookiesolution/iubenda-cookie-class/';
			$response = $observer->getResponse();
			$output = $response->getBody();

			require_once( $iubenda_path . 'iubenda.class.php' );

			if ( \iubendaParser::consent_given() || \iubendaParser::bot_detected() )
				return;

			$custom_scripts = $this->_helperData->get_custom_scripts();
			$custom_iframes = $this->_helperData->get_custom_iframes();

			if ( $this->_helperData->is_experimental_mode() )
				$iubenda = new \iubendaParser( mb_convert_encoding( $output, 'HTML-ENTITIES', 'UTF-8' ), array( 'type' => 'faster', 'scripts' => $custom_scripts, 'iframes' => $custom_iframes ) );
			else
				$iubenda = new \iubendaParser( $output, array( 'type' => 'page', 'scripts' => $custom_scripts, 'iframes' => $custom_iframes ) );

			// render output
			$output = $iubenda->parse();

			$response->setBody( $output );
		}
	}
}